Crate dinoco

Crate dinoco 

Re-exports

pub use futures;
pub use serde;

Structs

CachePolicy
CachedFindFirst
CachedFindMany
ConnectionUpdatePlan
Count
CountNode
DateTimeUtc
ISO 8601 combined date and time with time zone.
Delete
DeleteMany
DinocoCache
DinocoClient
DinocoClientConfig
DinocoQueryLog
DinocoQueryLogger
DinocoQueryLoggerOptions
FieldUpdate
FindAndUpdate
FindFirst
FindMany
IncludeNode
Insert
InsertMany
MySqlAdapter
NaiveDate
ISO 8601 calendar date without timezone. Allows for every proleptic Gregorian date from Jan 1, 262145 BCE to Dec 31, 262143 CE. Also supports the conversion from ISO 8601 ordinal and week date.
OrderBy
PostgresAdapter
QueueWorkerContext
QueueWorkers
RelationField
RelationLinkPlan
RelationMutationTarget
RelationMutationWhere
RelationQuery
RelationScalarField
RelationWritePlan
ScalarField
SelectStatement
SqliteAdapter
Update
UpdateField
UpdateMany
Utc
The UTC time zone. This is the most efficient time zone when you don’t need the local time. It is also used as an offset (which is also a dummy type).
Uuid
A Universally Unique Identifier (UUID).

Enums

DinocoError
DinocoRedisConfig
DinocoValue
Expression
JsonValue
Represents any valid JSON value.
OrderDirection
ReadMode
RelationWriteAction

Traits

AdapterDialect
DinocoAdapter
DinocoGenericRow
DinocoQueryLogWriter
DinocoRow
FindAndUpdateModel
InsertConnection
InsertConnectionPayload
InsertModel
InsertNested
InsertPayload
InsertRelation
IntoCountNode
IntoDinocoValue
IntoIncludeNode
Model
Projection
QueryBuilder
RelationMutationModel
ScalarFieldValue
UpdateModel

Functions

count
delete
delete_many
execute_connection_updates
execute_count
execute_delete
execute_find_and_update
execute_first
execute_insert
execute_insert_connected_payload
execute_insert_connected_payloads
execute_insert_payload
execute_insert_payload_returning
execute_insert_related_payload
execute_insert_related_payloads
execute_insert_relation_links
execute_insert_returning
execute_many
execute_relation_writes
execute_update
execute_update_many
execute_update_many_returning
execute_update_returning
find_and_update
find_first
find_many
insert_into
insert_many
qualify_expression
qualify_query_column
qualify_select_statement
snowflake
update
update_many
uuid_v7

Type Aliases

DinocoResult
IncludeApplier
IncludeLoaderFuture

Derive Macros

Extend
Rowable